@@ -1,6 +1,6 @@
 /* RCS common definitions and data structures
 
-   Copyright (C) 2010-2013 Thien-Thi Nguyen
+   Copyright (C) 2010-2014 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -26,6 +26,7 @@
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include "vla.h"
 
 #ifdef HAVE_LIMITS_H
 #include <limits.h>
@@ -44,6 +45,9 @@
 
 /* GCC attributes  */
 
+#define ARG_NONNULL(which)  _GL_ARG_NONNULL (which)
+#define ALL_NONNULL         _GL_ARG_NONNULL ()
+
 #define RCS_UNUSED  _GL_UNUSED
 
 #if __GNUC__ >= 3 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)
@@ -715,9 +719,6 @@ extern TINY_DECL (log);
 extern TINY_DECL (next);
 extern TINY_DECL (state);
 extern TINY_DECL (strict);
-#if COMPAT2
-extern TINY_DECL (suffix);
-#endif
 extern TINY_DECL (symbols);
 extern TINY_DECL (text);
 bool looking_at (struct tinysym const *sym, char const *start);
