@@ -1,6 +1,6 @@
 /* Change RCS file attributes.
 
-   Copyright (C) 2010-2013 Thien-Thi Nguyen
+   Copyright (C) 2010-2014 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -96,7 +96,7 @@ static void
 cleanup (int *exitstatus)
 {
   if (FLOW (erroneousp))
-    *exitstatus = EXIT_FAILURE;
+    *exitstatus = exit_failure;
   fro_zclose (&FLOW (from));
   Ozclose (&FLOW (res));
   ORCSclose ();
